@@ -3,15 +3,16 @@ package HTML::TurboForm::Element;
 use warnings;
 use strict;
 use base qw/ Class::Accessor /;
-__PACKAGE__->mk_accessors( qw/ params submit wrapper pure default dbsearchfield dbdata dbop dbid dblabel ignore_dbix type id name label text value request options optionsnum class left_class limit right_class row_class attributes table submit columns / );
+__PACKAGE__->mk_accessors( qw/ params submit wrapper errorclass pure default dbsearchfield dbdata optionstext dbop dbid dblabel ignore_dbix type id name label text value request options optionsnum class left_class limit right_class row_class attributes table submit columns / );
 
 sub new{
     my ($class, $request) = @_;
+	
     my $self = $class->SUPER::new( $request );
     $self->{view} ='';
     $self->{submitted} = 0;
     $self->{submitted} = 1 if ($request->{ $self->name });
-
+	
     if ($self->dbdata and $self->dbid and $self->dblabel){
        my @t = @{ $self->dbdata };
        foreach (@t){
@@ -123,7 +124,8 @@ sub vor{
     my $rtc='';
     my $ltc='';
     my $class='class="form_row"';
-
+    my $errorclass=" ".$self->errorclass if ($self->errorclass);
+	
     if ($self->{class}) {       $class='class="'.$self->{class}.'"'; }
     if ($self->{row_class}) {   $rwc  = " class='".$self->{row_class}."' ";  }
     if ($self->{right_class}) { $rtc  = " class='".$self->{right_class}."' "; }
@@ -133,9 +135,10 @@ sub vor{
         $error="<div class='form_error'>$error</div>" if ($error ne '');
         
         $self->label('') if (!$self->label);
+		$errorclass='' if (!$errorclass);
         $result=$table."<div ".$class.$rwc.">".$error.
                        "<div class='form_left'".$ltc.">".$self->label."</div>".
-                       "<div class='form_right'".$rtc.">";
+                       "<div class='form_right".$errorclass."'".$rtc.">";
 		       
 #$result=$table."<div ".$class.$rwc.">".$error.
 #                       "<div class='form_left'".$ltc.">".$self->label."</div>".
